#!/bin/bash
OUT=/tmp/crawler.output
ls 
cat pycaosdb.ini
python3 -c "import caosdb; print('CaosDB Version:', caosdb.__version__)"
rm -rf cache.db
echo "Clearing database"
python3 clear_database.py
echo "Testing crawler without cfoods"
python3 -m pytest test_crawler_basics.py
echo "Testing caching"
python3 -m pytest test_cache.py

echo "Filling the database"
./filldb.sh
echo "Testing the crawler database"
python3 -m pytest test_crawler_with_cfoods.py
echo "make a change"
pushd extroot
egrep -liRZ 'A description of another example' . | xargs -0 -l sed -i -e 's/A description of another example/A description of this example/g'
popd
echo "run crawler"
./crawl.py  / | tee $OUT
# check whether there was something UNAUTHORIZED
cat $OUT
set -e
grep "There where unauthorized changes" $OUT
# get the id of the run which is the last field of the output string
RUN_ID=$(grep "run id:" $OUT | awk '{ print $NF }')
echo $RUN_ID
echo "run crawler again"
echo "./crawl.py -a $RUN_ID /"
./crawl.py -a $RUN_ID / > $OUT
set +e
if grep "There where unauthorized changes" $OUT
then 
    exit 1
fi
set -e
echo "undo changes"
pushd extroot
egrep -liRZ 'A description of this example' . | xargs -0 -l sed -i -e 's/A description of this example/A description of another example/g'
popd
python3 test_table.py
# TODO the following test deletes lots of the data inserted by the crawler
echo "Testing im and export"
python3 test_im_und_export.py
# Better safe than sorry:
python3 clear_database.py

# Test correct display of data model errors:
echo "Testing recognition of data model problems ... "
python3 -m pytest test_datamodel_problems.py
python3 -m pytest test_crawl_with_datamodel_problems.py

echo "Testing table export"
python3 -m pytest test_base_table_exporter_integration.py

# Obsolete due to teardown in the above test.
# echo "/n/n/n YOU NEED TO RESTART THE SERVER TO REDO TESTS!!!"
